# Trulioo Ruby SDK

- Gem version: 1.0.3
- API version: v1
- Build package: org.openapitools.codegen.languages.RubyClientCodegen

## Installation

Ruby 2.4 or later is required.

### From [RubyGems](https://rubygems.org/)

```shell
gem install trulioo_sdk
```

### With local build

```shell
gem build trulioo_sdk.gemspec
gem install trulioo_sdk-1.0.0.gem
```

### As a dependency

Add the following line to the Gemfile:

```ruby
gem "trulioo_sdk", "~> 1.0.0"
```

## Sample Application

Check out our sample application for this SDK in the
[sample-app](https://github.com/Trulioo/sdk-ruby/tree/1.0.3/sample-app) folder.

## Getting Started

### Example of testing authentication

```ruby
require "trulioo_sdk"

config = Trulioo::Configuration.new()

# Configure API key authorization
config.api_key["ApiKeyAuth"] = "YOUR-X-TRULIOO-API-KEY"

# Configure mode: "trial" or "live"
mode = "trial"

# Initialize instance of Trulioo::ApiClient with config
api_client = Trulioo::ApiClient.new(config)

# Initialize instance of Trulioo::ConnectionApi with api_client
connection_api = Trulioo::ConnectionApi.new(api_client)

# Call Trulioo::ConnectionApi#test_authentication
begin
  result = connection_api.test_authentication(mode)
  puts(result)
rescue Trulioo::ApiError => error
  puts("Error when calling Trulioo::ConnectionApi#test_authentication")
  puts("HTTP status code: #{error.code}")
  puts("Response headers: #{error.response_headers}")
  puts("Response body: #{error.response_body}")
end
```

## Testing

Install [Bundler](https://bundler.io/) by running `gem install bundler`, then execute:

```shell
bundle install
bundle exec rake test
```

## Documentation for APIs

All URIs are relative to *https://gateway.trulioo.com*.

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Trulioo::BusinessApi* | [**get_business_search_result**](docs/BusinessApi.md#get_business_search_result) | **GET** /{mode}/business/v1/search/transactionrecord/{id} | Get Business Search Result
*Trulioo::BusinessApi* | [**search**](docs/BusinessApi.md#search) | **POST** /{mode}/business/v1/search | Search
*Trulioo::ConfigurationApi* | [**get_business_registration_numbers**](docs/ConfigurationApi.md#get_business_registration_numbers) | **GET** /{mode}/configuration/v1/businessregistrationnumbers/{countryCode}/{jurisdictionCode} | Get Business Registration Numbers
*Trulioo::ConfigurationApi* | [**get_consents**](docs/ConfigurationApi.md#get_consents) | **GET** /{mode}/configuration/v1/consents/{configurationName}/{countryCode} | Get Consents
*Trulioo::ConfigurationApi* | [**get_country_codes**](docs/ConfigurationApi.md#get_country_codes) | **GET** /{mode}/configuration/v1/countrycodes/{configurationName} | Get Country Codes
*Trulioo::ConfigurationApi* | [**get_country_subdivisions**](docs/ConfigurationApi.md#get_country_subdivisions) | **GET** /{mode}/configuration/v1/countrysubdivisions/{countryCode} | Get Country Subdivisions
*Trulioo::ConfigurationApi* | [**get_datasources**](docs/ConfigurationApi.md#get_datasources) | **GET** /{mode}/configuration/v1/datasources/{configurationName}/{countryCode} | Get Datasources
*Trulioo::ConfigurationApi* | [**get_detailed_consents**](docs/ConfigurationApi.md#get_detailed_consents) | **GET** /{mode}/configuration/v1/detailedConsents/{configurationName}/{countryCode} | Get Detailed Consents
*Trulioo::ConfigurationApi* | [**get_document_types**](docs/ConfigurationApi.md#get_document_types) | **GET** /{mode}/configuration/v1/documentTypes/{countryCode} | Get Document Types
*Trulioo::ConfigurationApi* | [**get_fields**](docs/ConfigurationApi.md#get_fields) | **GET** /{mode}/configuration/v1/fields/{configurationName}/{countryCode} | Get Fields
*Trulioo::ConfigurationApi* | [**get_recommended_fields**](docs/ConfigurationApi.md#get_recommended_fields) | **GET** /{mode}/configuration/v1/recommendedfields/{configurationName}/{countryCode} | Get Recommended Fields
*Trulioo::ConfigurationApi* | [**get_test_entities**](docs/ConfigurationApi.md#get_test_entities) | **GET** /{mode}/configuration/v1/testentities/{configurationName}/{countryCode} | Get Test Entities
*Trulioo::ConnectionApi* | [**connection_async_callback_url**](docs/ConnectionApi.md#connection_async_callback_url) | **POST** /{mode}/connection/v1/async-callback | Connection Async Callback Url
*Trulioo::ConnectionApi* | [**say_hello**](docs/ConnectionApi.md#say_hello) | **GET** /{mode}/connection/v1/sayhello/{name} | Say Hello
*Trulioo::ConnectionApi* | [**test_authentication**](docs/ConnectionApi.md#test_authentication) | **GET** /{mode}/connection/v1/testauthentication | Test Authentication
*Trulioo::VerificationsApi* | [**document_download**](docs/VerificationsApi.md#document_download) | **GET** /{mode}/verifications/v1/documentdownload/{transactionRecordId}/{fieldName} | Document Download
*Trulioo::VerificationsApi* | [**get_transaction_record**](docs/VerificationsApi.md#get_transaction_record) | **GET** /{mode}/verifications/v1/transactionrecord/{id} | Get Transaction Record
*Trulioo::VerificationsApi* | [**get_transaction_record_address**](docs/VerificationsApi.md#get_transaction_record_address) | **GET** /{mode}/verifications/v1/transactionrecord/{id}/withaddress | Get Transaction Record Address
*Trulioo::VerificationsApi* | [**get_transaction_record_document**](docs/VerificationsApi.md#get_transaction_record_document) | **GET** /{mode}/verifications/v1/transactionrecord/{transactionRecordID}/{documentField} | Get Transaction Record Document
*Trulioo::VerificationsApi* | [**get_transaction_record_verbose**](docs/VerificationsApi.md#get_transaction_record_verbose) | **GET** /{mode}/verifications/v1/transactionrecord/{id}/verbose | Get Transaction Record Verbose
*Trulioo::VerificationsApi* | [**get_transaction_status**](docs/VerificationsApi.md#get_transaction_status) | **GET** /{mode}/verifications/v1/transaction/{id}/status | Get Transaction Status
*Trulioo::VerificationsApi* | [**verify**](docs/VerificationsApi.md#verify) | **POST** /{mode}/verifications/v1/verify | Verify

## Documentation for Models

 - [Trulioo::Address](docs/Address.md)
 - [Trulioo::AppendedField](docs/AppendedField.md)
 - [Trulioo::Business](docs/Business.md)
 - [Trulioo::BusinessRecord](docs/BusinessRecord.md)
 - [Trulioo::BusinessRegistrationNumber](docs/BusinessRegistrationNumber.md)
 - [Trulioo::BusinessRegistrationNumberMask](docs/BusinessRegistrationNumberMask.md)
 - [Trulioo::BusinessResult](docs/BusinessResult.md)
 - [Trulioo::BusinessSearchRequest](docs/BusinessSearchRequest.md)
 - [Trulioo::BusinessSearchRequestBusinessSearchModel](docs/BusinessSearchRequestBusinessSearchModel.md)
 - [Trulioo::BusinessSearchResponse](docs/BusinessSearchResponse.md)
 - [Trulioo::BusinessSearchResponseIndustryCode](docs/BusinessSearchResponseIndustryCode.md)
 - [Trulioo::Communication](docs/Communication.md)
 - [Trulioo::Consent](docs/Consent.md)
 - [Trulioo::CountrySubdivision](docs/CountrySubdivision.md)
 - [Trulioo::DataField](docs/DataField.md)
 - [Trulioo::DataFields](docs/DataFields.md)
 - [Trulioo::DatasourceField](docs/DatasourceField.md)
 - [Trulioo::DatasourceResult](docs/DatasourceResult.md)
 - [Trulioo::Document](docs/Document.md)
 - [Trulioo::DriverLicence](docs/DriverLicence.md)
 - [Trulioo::Location](docs/Location.md)
 - [Trulioo::LocationAdditionalFields](docs/LocationAdditionalFields.md)
 - [Trulioo::NationalId](docs/NationalId.md)
 - [Trulioo::NormalizedDatasourceField](docs/NormalizedDatasourceField.md)
 - [Trulioo::NormalizedDatasourceGroupCountry](docs/NormalizedDatasourceGroupCountry.md)
 - [Trulioo::Passport](docs/Passport.md)
 - [Trulioo::PersonInfo](docs/PersonInfo.md)
 - [Trulioo::PersonInfoAdditionalFields](docs/PersonInfoAdditionalFields.md)
 - [Trulioo::Record](docs/Record.md)
 - [Trulioo::RecordRule](docs/RecordRule.md)
 - [Trulioo::Result](docs/Result.md)
 - [Trulioo::ServiceError](docs/ServiceError.md)
 - [Trulioo::TestEntityDataFields](docs/TestEntityDataFields.md)
 - [Trulioo::TransactionRecordResult](docs/TransactionRecordResult.md)
 - [Trulioo::TransactionRecordResultAllOf](docs/TransactionRecordResultAllOf.md)
 - [Trulioo::TransactionStatus](docs/TransactionStatus.md)
 - [Trulioo::VerifyRequest](docs/VerifyRequest.md)
 - [Trulioo::VerifyResult](docs/VerifyResult.md)

## Documentation for Authorization

### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: x-trulioo-api-key
- **Location**: HTTP header
