# Trulioo::BusinessApi

All URIs are relative to *https://gateway.trulioo.com*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**get_business_search_result**](BusinessApi.md#get_business_search_result) | **GET** /{mode}/business/v1/search/transactionrecord/{id} | Get Business Search Result |
| [**search**](BusinessApi.md#search) | **POST** /{mode}/business/v1/search | Search |


## get_business_search_result

> <BusinessSearchResponse> get_business_search_result(mode, id)

Get Business Search Result

returns the a business search result.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::BusinessApi.new
mode = 'mode_example' # String | trial or live
id = 'id_example' # String | transaction record id

begin
  # Get Business Search Result
  result = api_instance.get_business_search_result(mode, id)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling BusinessApi->get_business_search_result: #{e}"
end
```

#### Using the get_business_search_result_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BusinessSearchResponse>, Integer, Hash)> get_business_search_result_with_http_info(mode, id)

```ruby
begin
  # Get Business Search Result
  data, status_code, headers = api_instance.get_business_search_result_with_http_info(mode, id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BusinessSearchResponse>
rescue Trulioo::ApiError => e
  puts "Error when calling BusinessApi->get_business_search_result_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **id** | **String** | transaction record id |  |

### Return type

[**BusinessSearchResponse**](BusinessSearchResponse.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## search

> <BusinessSearchResponse> search(mode, business_search_request)

Search

Calling this method will perform a business search.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::BusinessApi.new
mode = 'mode_example' # String | trial or live
business_search_request = Trulioo::BusinessSearchRequest.new({country_code: 'country_code_example'}) # BusinessSearchRequest | 

begin
  # Search
  result = api_instance.search(mode, business_search_request)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling BusinessApi->search: #{e}"
end
```

#### Using the search_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<BusinessSearchResponse>, Integer, Hash)> search_with_http_info(mode, business_search_request)

```ruby
begin
  # Search
  data, status_code, headers = api_instance.search_with_http_info(mode, business_search_request)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <BusinessSearchResponse>
rescue Trulioo::ApiError => e
  puts "Error when calling BusinessApi->search_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **business_search_request** | [**BusinessSearchRequest**](BusinessSearchRequest.md) |  |  |

### Return type

[**BusinessSearchResponse**](BusinessSearchResponse.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: application/json, text/json
- **Accept**: application/json, text/json

