# Trulioo::ConfigurationApi

All URIs are relative to *https://gateway.trulioo.com*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**get_business_registration_numbers**](ConfigurationApi.md#get_business_registration_numbers) | **GET** /{mode}/configuration/v1/businessregistrationnumbers/{countryCode}/{jurisdictionCode} | Get Business Registration Numbers |
| [**get_consents**](ConfigurationApi.md#get_consents) | **GET** /{mode}/configuration/v1/consents/{configurationName}/{countryCode} | Get Consents |
| [**get_country_codes**](ConfigurationApi.md#get_country_codes) | **GET** /{mode}/configuration/v1/countrycodes/{configurationName} | Get Country Codes |
| [**get_country_subdivisions**](ConfigurationApi.md#get_country_subdivisions) | **GET** /{mode}/configuration/v1/countrysubdivisions/{countryCode} | Get Country Subdivisions |
| [**get_datasources**](ConfigurationApi.md#get_datasources) | **GET** /{mode}/configuration/v1/datasources/{configurationName}/{countryCode} | Get Datasources |
| [**get_detailed_consents**](ConfigurationApi.md#get_detailed_consents) | **GET** /{mode}/configuration/v1/detailedConsents/{configurationName}/{countryCode} | Get Detailed Consents |
| [**get_document_types**](ConfigurationApi.md#get_document_types) | **GET** /{mode}/configuration/v1/documentTypes/{countryCode} | Get Document Types |
| [**get_fields**](ConfigurationApi.md#get_fields) | **GET** /{mode}/configuration/v1/fields/{configurationName}/{countryCode} | Get Fields |
| [**get_recommended_fields**](ConfigurationApi.md#get_recommended_fields) | **GET** /{mode}/configuration/v1/recommendedfields/{configurationName}/{countryCode} | Get Recommended Fields |
| [**get_test_entities**](ConfigurationApi.md#get_test_entities) | **GET** /{mode}/configuration/v1/testentities/{configurationName}/{countryCode} | Get Test Entities |


## get_business_registration_numbers

> <Array<BusinessRegistrationNumber>> get_business_registration_numbers(mode, country_code, jurisdiction_code)

Get Business Registration Numbers

Gets the currently configured business registration numbers, for country and an optionally supplied jurisdiction

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::ConfigurationApi.new
mode = 'mode_example' # String | trial or live
country_code = 'country_code_example' # String | Country alpha2 code, get via the call to https://developer.trulioo.com/reference#getcountrycodes
jurisdiction_code = 'jurisdiction_code_example' # String | Optional jurisdiction code, get via the call to https://developer.trulioo.com/reference#getcountrysubdivisions

begin
  # Get Business Registration Numbers
  result = api_instance.get_business_registration_numbers(mode, country_code, jurisdiction_code)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_business_registration_numbers: #{e}"
end
```

#### Using the get_business_registration_numbers_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<BusinessRegistrationNumber>>, Integer, Hash)> get_business_registration_numbers_with_http_info(mode, country_code, jurisdiction_code)

```ruby
begin
  # Get Business Registration Numbers
  data, status_code, headers = api_instance.get_business_registration_numbers_with_http_info(mode, country_code, jurisdiction_code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<BusinessRegistrationNumber>>
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_business_registration_numbers_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **country_code** | **String** | Country alpha2 code, get via the call to https://developer.trulioo.com/reference#getcountrycodes |  |
| **jurisdiction_code** | **String** | Optional jurisdiction code, get via the call to https://developer.trulioo.com/reference#getcountrysubdivisions |  |

### Return type

[**Array&lt;BusinessRegistrationNumber&gt;**](BusinessRegistrationNumber.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_consents

> Array&lt;String&gt; get_consents(mode, configuration_name, country_code)

Get Consents

This method retrieves the consents required for data sources currently configured in your account configuration.   The response for this method contains a collection of strings that Verify method's ConsentForDataSources field expects to perform a verification using those data sources.   A failure to provide an element from the string collection will lead to a <a class=\"link-to-api\" href=\"#errors\">1005</a> service error.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::ConfigurationApi.new
mode = 'mode_example' # String | trial or live
configuration_name = 'configuration_name_example' # String | The product configuration. Currently \"Identity Verification\" for all products.
country_code = 'country_code_example' # String | Call CountryCodes to get the countries available to you.

begin
  # Get Consents
  result = api_instance.get_consents(mode, configuration_name, country_code)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_consents: #{e}"
end
```

#### Using the get_consents_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(Array&lt;String&gt;, Integer, Hash)> get_consents_with_http_info(mode, configuration_name, country_code)

```ruby
begin
  # Get Consents
  data, status_code, headers = api_instance.get_consents_with_http_info(mode, configuration_name, country_code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => Array&lt;String&gt;
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_consents_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **configuration_name** | **String** | The product configuration. Currently \&quot;Identity Verification\&quot; for all products. | [default to &#39;Identity Verification&#39;] |
| **country_code** | **String** | Call CountryCodes to get the countries available to you. |  |

### Return type

**Array&lt;String&gt;**

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_country_codes

> Array&lt;String&gt; get_country_codes(mode, configuration_name)

Get Country Codes

This method retrieves all the countries that are available to perform a verification.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::ConfigurationApi.new
mode = 'mode_example' # String | trial or live
configuration_name = 'configuration_name_example' # String | The product configuration. Currently \"Identity Verification\" for all products.

begin
  # Get Country Codes
  result = api_instance.get_country_codes(mode, configuration_name)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_country_codes: #{e}"
end
```

#### Using the get_country_codes_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(Array&lt;String&gt;, Integer, Hash)> get_country_codes_with_http_info(mode, configuration_name)

```ruby
begin
  # Get Country Codes
  data, status_code, headers = api_instance.get_country_codes_with_http_info(mode, configuration_name)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => Array&lt;String&gt;
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_country_codes_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **configuration_name** | **String** | The product configuration. Currently \&quot;Identity Verification\&quot; for all products. | [default to &#39;Identity Verification&#39;] |

### Return type

**Array&lt;String&gt;**

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_country_subdivisions

> <Array<CountrySubdivision>> get_country_subdivisions(mode, country_code)

Get Country Subdivisions

Gets the provinces states or other subdivisions for a country, mostly matches ISO 3166-2

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::ConfigurationApi.new
mode = 'mode_example' # String | trial or live
country_code = 'country_code_example' # String | Country alpha2 code, get the the call to countrycodes

begin
  # Get Country Subdivisions
  result = api_instance.get_country_subdivisions(mode, country_code)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_country_subdivisions: #{e}"
end
```

#### Using the get_country_subdivisions_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<CountrySubdivision>>, Integer, Hash)> get_country_subdivisions_with_http_info(mode, country_code)

```ruby
begin
  # Get Country Subdivisions
  data, status_code, headers = api_instance.get_country_subdivisions_with_http_info(mode, country_code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<CountrySubdivision>>
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_country_subdivisions_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **country_code** | **String** | Country alpha2 code, get the the call to countrycodes |  |

### Return type

[**Array&lt;CountrySubdivision&gt;**](CountrySubdivision.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_datasources

> <Array<NormalizedDatasourceGroupCountry>> get_datasources(mode, configuration_name, country_code)

Get Datasources

Gets datasource groups configured for your product and country.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::ConfigurationApi.new
mode = 'mode_example' # String | trial or live
configuration_name = 'configuration_name_example' # String | The product configuration. Currently \"Identity Verification\" for all products.
country_code = 'country_code_example' # String | Call CountryCodes to get the countries available to you.

begin
  # Get Datasources
  result = api_instance.get_datasources(mode, configuration_name, country_code)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_datasources: #{e}"
end
```

#### Using the get_datasources_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<NormalizedDatasourceGroupCountry>>, Integer, Hash)> get_datasources_with_http_info(mode, configuration_name, country_code)

```ruby
begin
  # Get Datasources
  data, status_code, headers = api_instance.get_datasources_with_http_info(mode, configuration_name, country_code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<NormalizedDatasourceGroupCountry>>
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_datasources_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **configuration_name** | **String** | The product configuration. Currently \&quot;Identity Verification\&quot; for all products. | [default to &#39;Identity Verification&#39;] |
| **country_code** | **String** | Call CountryCodes to get the countries available to you. |  |

### Return type

[**Array&lt;NormalizedDatasourceGroupCountry&gt;**](NormalizedDatasourceGroupCountry.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_detailed_consents

> <Array<Consent>> get_detailed_consents(mode, configuration_name, country_code)

Get Detailed Consents

This method retrieves details about consents required for data sources currently configured in your account configuration.   The response for this method contains a collection of objects.  Each object contains the Name of the data source, Text outlining what the user is consenting to, and optionally a Url where the user can find more information about how their data will be used.    Failure to provide a Name from the object collection will lead to a <a class=\"link-to-api\" href=\"#errors\">1005</a> service error.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::ConfigurationApi.new
mode = 'mode_example' # String | trial or live
configuration_name = 'configuration_name_example' # String | The product configuration. Currently \"Identity Verification\" for all products.
country_code = 'country_code_example' # String | Call CountryCodes to get the countries available to you.

begin
  # Get Detailed Consents
  result = api_instance.get_detailed_consents(mode, configuration_name, country_code)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_detailed_consents: #{e}"
end
```

#### Using the get_detailed_consents_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<Consent>>, Integer, Hash)> get_detailed_consents_with_http_info(mode, configuration_name, country_code)

```ruby
begin
  # Get Detailed Consents
  data, status_code, headers = api_instance.get_detailed_consents_with_http_info(mode, configuration_name, country_code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<Consent>>
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_detailed_consents_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **configuration_name** | **String** | The product configuration. Currently \&quot;Identity Verification\&quot; for all products. | [default to &#39;Identity Verification&#39;] |
| **country_code** | **String** | Call CountryCodes to get the countries available to you. |  |

### Return type

[**Array&lt;Consent&gt;**](Consent.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_document_types

> Hash&lt;String, Array&lt;String&gt;&gt; get_document_types(mode, country_code)

Get Document Types

Gets the document types available for a country.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::ConfigurationApi.new
mode = 'mode_example' # String | trial or live
country_code = 'country_code_example' # String | Call CountryCodes to get the countries available to you.

begin
  # Get Document Types
  result = api_instance.get_document_types(mode, country_code)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_document_types: #{e}"
end
```

#### Using the get_document_types_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(Hash&lt;String, Array&lt;String&gt;&gt;, Integer, Hash)> get_document_types_with_http_info(mode, country_code)

```ruby
begin
  # Get Document Types
  data, status_code, headers = api_instance.get_document_types_with_http_info(mode, country_code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => Hash&lt;String, Array&lt;String&gt;&gt;
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_document_types_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **country_code** | **String** | Call CountryCodes to get the countries available to you. |  |

### Return type

**Hash&lt;String, Array&lt;String&gt;&gt;**

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_fields

> Object get_fields(mode, configuration_name, country_code)

Get Fields

Generates json schema for the API, the schema is dynamic based on the country and configuration you are using.  http://json-schema.org/documentation.html

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::ConfigurationApi.new
mode = 'mode_example' # String | trial or live
configuration_name = 'configuration_name_example' # String | The product configuration. Currently \"Identity Verification\" for all products.
country_code = 'country_code_example' # String | Call CountryCodes to get the countries available to you.

begin
  # Get Fields
  result = api_instance.get_fields(mode, configuration_name, country_code)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_fields: #{e}"
end
```

#### Using the get_fields_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(Object, Integer, Hash)> get_fields_with_http_info(mode, configuration_name, country_code)

```ruby
begin
  # Get Fields
  data, status_code, headers = api_instance.get_fields_with_http_info(mode, configuration_name, country_code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => Object
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_fields_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **configuration_name** | **String** | The product configuration. Currently \&quot;Identity Verification\&quot; for all products. | [default to &#39;Identity Verification&#39;] |
| **country_code** | **String** | Call CountryCodes to get the countries available to you. |  |

### Return type

**Object**

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_recommended_fields

> Object get_recommended_fields(mode, configuration_name, country_code)

Get Recommended Fields

Generates json schema for the API, the schema is dynamic based on the recommendedFields country and account you are using.  http://json-schema.org/documentation.html

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::ConfigurationApi.new
mode = 'mode_example' # String | trial or live
configuration_name = 'configuration_name_example' # String | The product configuration. Currently \"Identity Verification\" for all products.
country_code = 'country_code_example' # String | Call CountryCodes to get the countries available to you.

begin
  # Get Recommended Fields
  result = api_instance.get_recommended_fields(mode, configuration_name, country_code)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_recommended_fields: #{e}"
end
```

#### Using the get_recommended_fields_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(Object, Integer, Hash)> get_recommended_fields_with_http_info(mode, configuration_name, country_code)

```ruby
begin
  # Get Recommended Fields
  data, status_code, headers = api_instance.get_recommended_fields_with_http_info(mode, configuration_name, country_code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => Object
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_recommended_fields_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **configuration_name** | **String** | The product configuration. Currently \&quot;Identity Verification\&quot; for all products. | [default to &#39;Identity Verification&#39;] |
| **country_code** | **String** | Call CountryCodes to get the countries available to you. |  |

### Return type

**Object**

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_test_entities

> <Array<TestEntityDataFields>> get_test_entities(mode, configuration_name, country_code)

Get Test Entities

Gets the test entities configured for your product and country.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::ConfigurationApi.new
mode = 'mode_example' # String | trial or live
configuration_name = 'configuration_name_example' # String | The product configuration. Currently \"Identity Verification\" for all products.
country_code = 'country_code_example' # String | Call CountryCodes to get the countries available to you.

begin
  # Get Test Entities
  result = api_instance.get_test_entities(mode, configuration_name, country_code)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_test_entities: #{e}"
end
```

#### Using the get_test_entities_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<TestEntityDataFields>>, Integer, Hash)> get_test_entities_with_http_info(mode, configuration_name, country_code)

```ruby
begin
  # Get Test Entities
  data, status_code, headers = api_instance.get_test_entities_with_http_info(mode, configuration_name, country_code)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<TestEntityDataFields>>
rescue Trulioo::ApiError => e
  puts "Error when calling ConfigurationApi->get_test_entities_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **configuration_name** | **String** | The product configuration. Currently \&quot;Identity Verification\&quot; for all products. | [default to &#39;Identity Verification&#39;] |
| **country_code** | **String** | Call CountryCodes to get the countries available to you. |  |

### Return type

[**Array&lt;TestEntityDataFields&gt;**](TestEntityDataFields.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json

