# Trulioo::ConnectionApi

All URIs are relative to *https://gateway.trulioo.com*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**connection_async_callback_url**](ConnectionApi.md#connection_async_callback_url) | **POST** /{mode}/connection/v1/async-callback | Connection Async Callback Url |
| [**say_hello**](ConnectionApi.md#say_hello) | **GET** /{mode}/connection/v1/sayhello/{name} | Say Hello |
| [**test_authentication**](ConnectionApi.md#test_authentication) | **GET** /{mode}/connection/v1/testauthentication | Test Authentication |


## connection_async_callback_url

> Object connection_async_callback_url(mode, transaction_status)

Connection Async Callback Url

If set, the transaction will run asynchronously and Trulioo will try to update the client with transaction state updates until completed. If callback is not desired but the client wants to initiate an asynchronous transaction, provide https://api.globaldatacompany.com/connection/v1/async-callback as the Callback URL.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'

api_instance = Trulioo::ConnectionApi.new
mode = 'mode_example' # String | trial or live
transaction_status = Trulioo::TransactionStatus.new # TransactionStatus | transactionStatus

begin
  # Connection Async Callback Url
  result = api_instance.connection_async_callback_url(mode, transaction_status)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling ConnectionApi->connection_async_callback_url: #{e}"
end
```

#### Using the connection_async_callback_url_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(Object, Integer, Hash)> connection_async_callback_url_with_http_info(mode, transaction_status)

```ruby
begin
  # Connection Async Callback Url
  data, status_code, headers = api_instance.connection_async_callback_url_with_http_info(mode, transaction_status)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => Object
rescue Trulioo::ApiError => e
  puts "Error when calling ConnectionApi->connection_async_callback_url_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **transaction_status** | [**TransactionStatus**](TransactionStatus.md) | transactionStatus |  |

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json, text/json
- **Accept**: application/json, text/json


## say_hello

> String say_hello(mode, name)

Say Hello

This method enables you to check if your system can connect to our system. You can even use a web browser to verify a connection to our system.  Applied a maximum length for the name parameter of 100 via a route constraint

### Examples

```ruby
require 'time'
require 'trulioo_sdk'

api_instance = Trulioo::ConnectionApi.new
mode = 'mode_example' # String | trial or live
name = 'name_example' # String | Name to be returned in the response

begin
  # Say Hello
  result = api_instance.say_hello(mode, name)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling ConnectionApi->say_hello: #{e}"
end
```

#### Using the say_hello_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(String, Integer, Hash)> say_hello_with_http_info(mode, name)

```ruby
begin
  # Say Hello
  data, status_code, headers = api_instance.say_hello_with_http_info(mode, name)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => String
rescue Trulioo::ApiError => e
  puts "Error when calling ConnectionApi->say_hello_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **name** | **String** | Name to be returned in the response |  |

### Return type

**String**

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## test_authentication

> String test_authentication(mode)

Test Authentication

This method enables you to check if your credentials are valid. You will need to use basic authentication to ensure a successful response.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::ConnectionApi.new
mode = 'mode_example' # String | trial or live

begin
  # Test Authentication
  result = api_instance.test_authentication(mode)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling ConnectionApi->test_authentication: #{e}"
end
```

#### Using the test_authentication_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(String, Integer, Hash)> test_authentication_with_http_info(mode)

```ruby
begin
  # Test Authentication
  data, status_code, headers = api_instance.test_authentication_with_http_info(mode)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => String
rescue Trulioo::ApiError => e
  puts "Error when calling ConnectionApi->test_authentication_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |

### Return type

**String**

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json

