# Trulioo::VerificationsApi

All URIs are relative to *https://gateway.trulioo.com*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**document_download**](VerificationsApi.md#document_download) | **GET** /{mode}/verifications/v1/documentdownload/{transactionRecordId}/{fieldName} | Document Download |
| [**get_transaction_record**](VerificationsApi.md#get_transaction_record) | **GET** /{mode}/verifications/v1/transactionrecord/{id} | Get Transaction Record |
| [**get_transaction_record_address**](VerificationsApi.md#get_transaction_record_address) | **GET** /{mode}/verifications/v1/transactionrecord/{id}/withaddress | Get Transaction Record Address |
| [**get_transaction_record_document**](VerificationsApi.md#get_transaction_record_document) | **GET** /{mode}/verifications/v1/transactionrecord/{transactionRecordID}/{documentField} | Get Transaction Record Document |
| [**get_transaction_record_verbose**](VerificationsApi.md#get_transaction_record_verbose) | **GET** /{mode}/verifications/v1/transactionrecord/{id}/verbose | Get Transaction Record Verbose |
| [**get_transaction_status**](VerificationsApi.md#get_transaction_status) | **GET** /{mode}/verifications/v1/transaction/{id}/status | Get Transaction Status |
| [**verify**](VerificationsApi.md#verify) | **POST** /{mode}/verifications/v1/verify | Verify |


## document_download

> Object document_download(mode, transaction_record_id, field_name)

Document Download

Download Document

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::VerificationsApi.new
mode = 'mode_example' # String | trial or live
transaction_record_id = 'transaction_record_id_example' # String | id of the transactionrecord, this will be a GUID
field_name = 'field_name_example' # String | document field name

begin
  # Document Download
  result = api_instance.document_download(mode, transaction_record_id, field_name)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->document_download: #{e}"
end
```

#### Using the document_download_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(Object, Integer, Hash)> document_download_with_http_info(mode, transaction_record_id, field_name)

```ruby
begin
  # Document Download
  data, status_code, headers = api_instance.document_download_with_http_info(mode, transaction_record_id, field_name)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => Object
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->document_download_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **transaction_record_id** | **String** | id of the transactionrecord, this will be a GUID |  |
| **field_name** | **String** | document field name |  |

### Return type

**Object**

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_transaction_record

> <TransactionRecordResult> get_transaction_record(mode, id)

Get Transaction Record

This method is used to retrieve the request and results of a verification performed using the verify method.  The response for this method includes the same information as verify method's response, along with data present in the input fields of the verify request.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::VerificationsApi.new
mode = 'mode_example' # String | trial or live
id = 'id_example' # String | id of the transactionrecord, this will be a GUID

begin
  # Get Transaction Record
  result = api_instance.get_transaction_record(mode, id)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->get_transaction_record: #{e}"
end
```

#### Using the get_transaction_record_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionRecordResult>, Integer, Hash)> get_transaction_record_with_http_info(mode, id)

```ruby
begin
  # Get Transaction Record
  data, status_code, headers = api_instance.get_transaction_record_with_http_info(mode, id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionRecordResult>
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->get_transaction_record_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **id** | **String** | id of the transactionrecord, this will be a GUID |  |

### Return type

[**TransactionRecordResult**](TransactionRecordResult.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_transaction_record_address

> <TransactionRecordResult> get_transaction_record_address(mode, id)

Get Transaction Record Address

Fetch the results of a verification with the TransactionRecordId for the transaction this will include additional information if your account  includes address cleansing.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::VerificationsApi.new
mode = 'mode_example' # String | trial or live
id = 'id_example' # String | id of the transactionrecord, this will be a GUID

begin
  # Get Transaction Record Address
  result = api_instance.get_transaction_record_address(mode, id)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->get_transaction_record_address: #{e}"
end
```

#### Using the get_transaction_record_address_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionRecordResult>, Integer, Hash)> get_transaction_record_address_with_http_info(mode, id)

```ruby
begin
  # Get Transaction Record Address
  data, status_code, headers = api_instance.get_transaction_record_address_with_http_info(mode, id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionRecordResult>
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->get_transaction_record_address_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **id** | **String** | id of the transactionrecord, this will be a GUID |  |

### Return type

[**TransactionRecordResult**](TransactionRecordResult.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_transaction_record_document

> String get_transaction_record_document(mode, transaction_record_id, document_field)

Get Transaction Record Document

This method is used to retrieve the document of a verification performed using the verify method.  The response for this method includes the processed base64 JPEG formatted string

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::VerificationsApi.new
mode = 'mode_example' # String | trial or live
transaction_record_id = 'transaction_record_id_example' # String | id of the transactionrecord, this will be a GUID
document_field = 'document_field_example' # String | FieldName of the Document, this will be a string

begin
  # Get Transaction Record Document
  result = api_instance.get_transaction_record_document(mode, transaction_record_id, document_field)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->get_transaction_record_document: #{e}"
end
```

#### Using the get_transaction_record_document_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(String, Integer, Hash)> get_transaction_record_document_with_http_info(mode, transaction_record_id, document_field)

```ruby
begin
  # Get Transaction Record Document
  data, status_code, headers = api_instance.get_transaction_record_document_with_http_info(mode, transaction_record_id, document_field)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => String
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->get_transaction_record_document_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **transaction_record_id** | **String** | id of the transactionrecord, this will be a GUID |  |
| **document_field** | **String** | FieldName of the Document, this will be a string |  |

### Return type

**String**

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_transaction_record_verbose

> <TransactionRecordResult> get_transaction_record_verbose(mode, id)

Get Transaction Record Verbose

Fetch the results of a verification with the TransactionRecordId for the transaction this will include additional information if your account  includes address cleansing and watchlist details.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::VerificationsApi.new
mode = 'mode_example' # String | trial or live
id = 'id_example' # String | id of the transactionrecord, this will be a GUID

begin
  # Get Transaction Record Verbose
  result = api_instance.get_transaction_record_verbose(mode, id)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->get_transaction_record_verbose: #{e}"
end
```

#### Using the get_transaction_record_verbose_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionRecordResult>, Integer, Hash)> get_transaction_record_verbose_with_http_info(mode, id)

```ruby
begin
  # Get Transaction Record Verbose
  data, status_code, headers = api_instance.get_transaction_record_verbose_with_http_info(mode, id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionRecordResult>
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->get_transaction_record_verbose_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **id** | **String** | id of the transactionrecord, this will be a GUID |  |

### Return type

[**TransactionRecordResult**](TransactionRecordResult.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## get_transaction_status

> <TransactionStatus> get_transaction_status(mode, id)

Get Transaction Status

This method is used to retrieve the processing status of an asynchronous transaction. The response for this method includes the processing status of the verification, the TransactionID, the TransactionRecordID as well as whether the verification request has timed out.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::VerificationsApi.new
mode = 'mode_example' # String | trial or live
id = 'id_example' # String | id of the asynchronous transaction, this will be a GUID

begin
  # Get Transaction Status
  result = api_instance.get_transaction_status(mode, id)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->get_transaction_status: #{e}"
end
```

#### Using the get_transaction_status_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<TransactionStatus>, Integer, Hash)> get_transaction_status_with_http_info(mode, id)

```ruby
begin
  # Get Transaction Status
  data, status_code, headers = api_instance.get_transaction_status_with_http_info(mode, id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <TransactionStatus>
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->get_transaction_status_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **id** | **String** | id of the asynchronous transaction, this will be a GUID |  |

### Return type

[**TransactionStatus**](TransactionStatus.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json, text/json


## verify

> <VerifyResult> verify(mode, verify_request)

Verify

Calling this method will perform a verification. If your account includes address cleansing set the CleansedAddress flag to get  additional address information in the result.  You can query configuration to get what fields are available to you in each each country.  It is also possible to get sample requests from the customer portal.

### Examples

```ruby
require 'time'
require 'trulioo_sdk'
# setup authorization
Trulioo.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['ApiKeyAuth'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKeyAuth'] = 'Bearer'
end

api_instance = Trulioo::VerificationsApi.new
mode = 'mode_example' # String | trial or live
verify_request = Trulioo::VerifyRequest.new({country_code: 'country_code_example', data_fields: Trulioo::DataFields.new}) # VerifyRequest | 

begin
  # Verify
  result = api_instance.verify(mode, verify_request)
  p result
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->verify: #{e}"
end
```

#### Using the verify_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<VerifyResult>, Integer, Hash)> verify_with_http_info(mode, verify_request)

```ruby
begin
  # Verify
  data, status_code, headers = api_instance.verify_with_http_info(mode, verify_request)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <VerifyResult>
rescue Trulioo::ApiError => e
  puts "Error when calling VerificationsApi->verify_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **mode** | **String** | trial or live | [default to &#39;trial&#39;] |
| **verify_request** | [**VerifyRequest**](VerifyRequest.md) |  |  |

### Return type

[**VerifyResult**](VerifyResult.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: application/json, text/json
- **Accept**: application/json, text/json

